@@ -3,19 +3,18 @@
 # Imports
 import json as __json
 from ..error import SfcparseError
+from typing import Union
 
 # Exception for Module
-class _Jsonexportfile: 
-    class jsonexportfile(SfcparseError): __module__ = SfcparseError.set_module_name()
-
+class JsonExportFile(SfcparseError): __module__ = SfcparseError.set_module_name()
 
 #########################################################################################################
 # Export json file
-def jsonexportfile(filename: str, data: dict) -> None:
+def jsonexportfile(filename: str, data: Union[str, int, float, bool, list, dict, tuple, None]) -> None:
     """
-    Exports a new file from a dictionary to json data.
+    Exports a new file from python data type to json data.
     
-    Enter new filename as str. Pass dict data for output to file
+    Enter new filename as str. Pass data for output to file
     
     [Example Use]
 
@@ -26,9 +25,9 @@ def jsonexportfile(filename: str, data: dict) -> None:
     
     """
     try:
-        # Export dict data to json file
+        # Export data to json file
         with open(filename, 'w') as f:
             __json.dump(data, f)
-    except TypeError as __err_msg: raise _Jsonexportfile.jsonexportfile(__err_msg, f'\nFILE:"{filename}" \nDATA:{data}')
-    except ValueError as __err_msg: raise _Jsonexportfile.jsonexportfile(__err_msg, f'\nFILE:"{filename}" \nDATA:{data}')
-    except FileNotFoundError as __err_msg: raise _Jsonexportfile.jsonexportfile(__err_msg, f'\nFILE:"{filename}"')
+    except TypeError as __err_msg: raise JsonExportFile(__err_msg, f'\nFILE: "{filename}" \nDATA:{data}')
+    except ValueError as __err_msg: raise JsonExportFile(__err_msg, f'\nFILE: "{filename}" \nDATA:{data}')
+    except FileNotFoundError as __err_msg: raise JsonExportFile(__err_msg, f'\nFILE: "{filename}"')
