@@ -1,22 +1,20 @@
 # jsonimportfile
 #########################################################################################################
 # Imports
-from os import path as __path
 import json as __json
 from ..error import SfcparseError
+from typing import Union
 
 # Exception for Module
-class _Jsonimportfile: 
-    class jsonimportfile(SfcparseError): __module__ = SfcparseError.set_module_name()
-
+class JsonImportFile(SfcparseError): __module__ = SfcparseError.set_module_name()
 
 #########################################################################################################
 # Import json file
-def jsonimportfile(filename: str) -> dict:
+def jsonimportfile(filename: str) -> Union[list, dict, str, int, float, bool, None]:
     """
     Imports json data from a file
 
-    Returns a dict. Assign the output to var
+    Returns data with matching python data type. Assign the output to var
 
     Enter json file location as str to import.
 
@@ -30,10 +28,8 @@ def jsonimportfile(filename: str) -> dict:
     # Import json file
     try:
         with open(filename, 'r') as f:
-            # Check if file empty. Returns empty dict if empty
-            if __path.getsize(filename) == 0:                
-                raise SyntaxError(__err_msg)
             return __json.load(f)
-    except FileNotFoundError as __err_msg: raise _Jsonimportfile.jsonimportfile(__err_msg, f'\nFILE:"{filename}"')
-    except OSError as __err_msg: raise _Jsonimportfile.jsonimportfile(__err_msg, f'\nFILE:"{filename}"')
-    except __json.decoder.JSONDecodeError as __err_msg: raise _Jsonimportfile.jsonimportfile(__err_msg, f'\nFILE:"{filename}"')
+    except FileNotFoundError as __err_msg: raise JsonImportFile(__err_msg, f'\nFILE: "{filename}"')
+    except OSError as __err_msg: raise JsonImportFile(__err_msg, f'\nFILE: "{filename}"')
+    except TypeError as __err_msg: raise JsonImportFile(__err_msg, f'\nFILE: "{filename}"')
+    except __json.decoder.JSONDecodeError as __err_msg: raise JsonImportFile(__err_msg, f'\nFILE: "{filename}"')
